@@ -331,11 +331,45 @@ def parse_args(args=[]):
 
         Examples: \n
         \t - Use a different editor for this jrnl entry, call: \n
-            \t jrnl --config-override editor: "nano" \n
+            \t jrnl --config-override editor "nano" \n
         \t - Override color selections\n
            \t jrnl --config-override colors.body blue --config-override colors.title green
         """,
     )
+    config_overrides.add_argument(
+        "--co",
+        dest="config_override",
+        action="append",
+        type=str,
+        nargs=2,
+        default=[],
+        help=argparse.SUPPRESS,
+    )
+
+    alternate_config = parser.add_argument_group(
+        "Specifies alternate config to be used",
+        textwrap.dedent("Applies alternate config for current session"),
+    )
+
+    alternate_config.add_argument(
+        "--config-file",
+        dest="config_file_path",
+        type=str,
+        default="",
+        help="""
+        Overrides default (created when first installed) config file for this command only.
+        
+        Examples: \n
+        \t - Use a work config file for this jrnl entry, call: \n
+            \t jrnl --config-file /home/user1/work_config.yaml
+        \t - Use a personal config file stored on a thumb drive: \n
+            \t jrnl --config-file /media/user1/my-thumb-drive/personal_config.yaml
+        """,
+    )
+
+    alternate_config.add_argument(
+        "--cf", dest="config_file_path", type=str, default="", help=argparse.SUPPRESS
+    )
 
     # Handle '-123' as a shortcut for '-n 123'
     num = re.compile(r"^-(\d+)$")
