@@ -20,6 +20,7 @@ DEFAULT_JOURNAL_NAME = "journal.txt"
 DEFAULT_JOURNAL_KEY = "default"
 
 YAML_SEPARATOR = ": "
+YAML_FILE_ENCODING = "utf-8"
 
 
 def make_yaml_valid_dict(input: list) -> dict:
@@ -46,11 +47,20 @@ def make_yaml_valid_dict(input: list) -> dict:
     return runtime_modifications
 
 
-def save_config(config):
+def save_config(config, alt_config_path=None):
+    """Supply alt_config_path if using an alternate config through --config-file."""
     config["version"] = __version__
-    with open(get_config_path(), "w") as f:
+    with open(
+        alt_config_path if alt_config_path else get_config_path(),
+        "w",
+        encoding=YAML_FILE_ENCODING,
+    ) as f:
         yaml.safe_dump(
-            config, f, encoding="utf-8", allow_unicode=True, default_flow_style=False
+            config,
+            f,
+            encoding=YAML_FILE_ENCODING,
+            allow_unicode=True,
+            default_flow_style=False,
         )
 
 
@@ -79,7 +89,7 @@ def get_default_config():
         "default_hour": 9,
         "default_minute": 0,
         "timeformat": "%Y-%m-%d %H:%M",
-        "tagsymbols": "@",
+        "tagsymbols": "#@",
         "highlight": True,
         "linewrap": 79,
         "indent_character": "|",
@@ -139,7 +149,7 @@ def verify_config_colors(config):
 
 def load_config(config_path):
     """Tries to load a config file from YAML."""
-    with open(config_path) as f:
+    with open(config_path, encoding=YAML_FILE_ENCODING) as f:
         return yaml.load(f, Loader=yaml.SafeLoader)
 
 
